# Sewise Player接口方法说明

## 一、点、直播通用接口方法
### doPlay()
* 说明：启动、恢复播放
* 参数：无
* 返回：无
* 示例：
```javascript
SewisePlayer.doPlay();
```

### doPause()
* 说明：暂停播放
* 参数：无
* 返回：无
* 示例：
```javascript
SewisePlayer.doPause();
```

### doStop()
* 说明：停止播放
* 参数：无
* 返回：无
* 示例：
```javascript
SewisePlayer.doStop();
```

### doSeek(time)
* 说明：跳转播放
* 参数：time类型点播时为数值表示要跳转到的位置（秒），直播时为字符串表示要跳转到的日期（如：'20130503123456'）
* 返回：无
* 示例：
* 点播 
```javascript
SewisePlayer.doSeek(20);
```
* 直播 
```javascript
SewisePlayer.doSeek("20130503123055");
```

### toPlay(url, title, startTime, autoPlay)
* 说明：根据视频地址播放视频
* 参数：url类型为字符串表示要播放的视频地址，title类型为字符串表示视频标题，startTime类型点播时为数值表示开始播放的位置（秒）。 直播时为字符串表示开始播放位置的日期（如：'20130503123456'），autoPlay类型为布尔值表示是否自动开始播放。另，直播时当流地址后添加了14位的开始时间和结束时间后（如："rtmp://192.168.1.219/livestream/qq3tvegb_20130812094010_20130812094210"），流将从开始时间点播放到结束时间点后停止流播放。
* 返回：无
* 示例：
* 点播
```javascript
SewisePlayer.toPlay("http://192.168.1.219:5080/flvseek/data/26144610yg.flv","深圳卫视", 20, true); 
```
* 直播 
```javascript
SewisePlayer.toPlay("rtmp://192.168.1.219/livestream/6jzcdjgi", "深圳卫视", "20130927150000", true);
```

### setVolume(volue)
* 说明：设置音量
* 参数：volue类型为数值（0 - 1）,表示要设置的音量值
* 返回：无
* 示例：
```javascript
SewisePlayer.setVolume(0.5);
```

### playTime()
* 说明：获取当前播放时间位置、日期
* 参数：无
* 返回：点播返回当前视频播放到的位置（秒）。直播返回当前视频播放到的时间点（日期）
* 示例：
```javascript
SewisePlayer.playTime();
```

### fullScreen()
* 说明：进入全屏播放
* 参数：无
* 返回：无
* 示例：
```javascript
SewisePlayer.fullScreen();
```

### noramlScreen()
* 说明：退出全屏播放
* 参数：无
* 返回：无
* 示例：
```javascript
SewisePlayer.noramlScreen();
```

### bufferProgress()
* 说明：获取当前缓冲进度
* 参数：无
* 返回：当前缓冲进度比
* 示例：
```javascript
SewisePlayer.bufferProgress();
```

## 二、点、直播专用接口方法
### 1.点播专用方法
### playProgram(pid, startTime, autoPlay)
* 说明：通过节目ID来播放视频
* 参数：无
* 返回：pid类型为字符串表示节目ID，startTime类型为数值表示视频开始播放的位置（秒），autoPlay类型为布尔值表示是否自动开始播放
* 示例：
```javascript
SewisePlayer.playProgram("jCAH3SAY", 20, true);
```

### duration()
* 说明：获取视频的总时长
* 参数：无
* 返回：返回当前播放视频的总时长
* 示例：
```javascript
SewisePlayer.duration();
```

### 2.直播专用方法
### doLive()
* 说明：回到直播
* 参数：无
* 返回：无
* 示例：
```javascript
SewisePlayer.doLive();
```

### playChannel(cid, startTime, autoPlay)
* 说明：通过频道ID来播放视频
* 参数：cid类型为字符串表示节目ID，startTime类型为字符串表示开始播放的时间点（日期）（如：'20130503123456'），autoPlay类型为布尔值表示是否自动开始播放
* 返回：无
* 示例：
```javascript
SewisePlayer.playChannel("y894tgf3", "20130503123456", true);
```

### liveTime()
* 说明：获取最新直播时间
* 参数：无
* 返回：当前视频最新的直播时间日期
* 示例：
```javascript
SewisePlayer.liveTime();
```

### setDuration(duration)
* 说明：设置直接时间跨度
* 参数：duration类型为数值，表示播放进度条上规化的时长。
* 返回：无
* 示例：
```javascript
SewisePlayer.setDuration(645);
```

## 三、播放器回调的函数
### 1、点、直播通用回调函数
### playerReady(id)
* 说明：播放器准备好后回调的函数
* 参数：id类型为字符串，表示播放器当前id。
* 返回：无
* 示例：
```javascript
function playerReady(id) {
	SewisePlayer.doSeek(10);
}
或
SewisePlayer.playerReady(function(id){
	SewisePlayer.doSeek(10);
});
```

### onStart(id)
* 说明：视频开始播放后回调的函数
* 参数：无
* 返回：id，播放器当前id。
* 示例：
```javascript
function onStart(id){
	console.log("play start 1")
}
或
SewisePlayer.onStart(function(id){
	 console.log("play start 2");
});
```

### onPause(id)
* 说明：视频暂停播放后回调的函数
* 参数：id，播放器当前id。
* 返回：无
* 示例：
```javascript
function onPause(id){
	console.log("play pause 1")
}
或
SewisePlayer.onPause(function(id){
	 console.log("play pause 2");
});
```

### onStop(id)
* 说明：视频停止播放后回调的函数
* 参数：id，播放器当前id。
* 返回：无
* 示例：
```javascript
function onStop(id){
	console.log("play stopped 1")
}
或
SewisePlayer.onStop(function(id){
	 console.log("play stopped 2");
});
```

### onSeek(time, id)
* 说明：视频时移播放后回调的函数
* 参数：time时移时间点，id，播放器当前id。
* 返回：无
* 示例：
```javascript
function onSeek(time, id){
	console.log("play seek 1: " + time)
}
或
SewisePlayer.onSeek(function(time, id){
	console.log("play seek 2: " + time);
});
```

### onPlayTime(time, id)
* 说明：视频实时播放回调
* 参数：time, id。time当前播放头位置，id，播放器当前id。
* 返回：无
* 示例：
```javascript
function onPlayTime(time, id){
	console.log("onPlayTime 1: " + time);
}
或
SewisePlayer.onPlayTime(function(time, id){
	console.log("onPlayTime 2: " + time);
});
```

### onMetadata(meta, id)
* 说明：播放器获取到播放视频metadata信息后回调的函数
* 参数：meta类型为JSON对象，表示metadata信息数据对象，id，播放器当前id。
* 返回：无
* 示例：
```javascript
function onMetadata(meta, id){
	console.log("onMetadata 1");
}
或
SewisePlayer.onMetadata(function(meta, id){
	 console.log("onMetadata 2");
});
```

### onClarity(clarity, id)
* 说明：切换清晰度后回调的函数
* 参数：clarity类型为Object对象，表示清晰度信息数据对象，id，播放器当前id。
* 返回：无
* 示例：
```javascript
function onClarity(clarity, id){
	console.log(clarity.id + "\n" + clarity.name + '\n' + clarity.videoUrl);
}
或
SewisePlayer.onClarity(function(clarity, id){
	 console.log(clarity.id + "\n" + clarity.name + '\n' + clarity.videoUrl);
});
```

### onBuffer(pt, id)
* 说明：播放器进入缓冲后回调的函数
* 参数：pt, id。pt当前缓冲下载进度比，id，播放器当前id。
* 返回：无
* 示例：
```javascript
function onBuffer(pt, id){
	console.log("onBuffer 1: " + pt);
}
或
SewisePlayer.onBuffer(function(pt, id){
	console.log("onBuffer 2: " + pt);
});
```